@@ -26,6 +26,7 @@ class Postgres_Handler:
             with conn.cursor() as cursor:
         
                 try:
+                    print(query)
                     cursor.execute(query, values)
                     results = cursor.fetchall()
 
@@ -159,7 +160,7 @@ class Postgres_Handler:
         # table_name = kwargs[self.table_name_key]
         
         #Begining of the SQL query
-        query = sql(
+        query = sql.SQL(
             'INSERT INTO {table_name} ({columns}) VALUES({values})'.format(
                 columns = sql.SQL(', ').join(
                     map(sql.Identifier, kwargs.keys())
